%define oname   Mnemosyne

Name:           mnemosyne
Version:        2.11
Release:        %mkrel 2
Summary:        Flash-card learning tool which optimizes the learning process
Group:          Education
License:        AGPLv3 and LGPLv3
URL:            https://mnemosyne-proj.org
# see also      https://github.com/mnemosyne-proj/mnemosyne
Source0:        https://github.com/mnemosyne-proj/mnemosyne/archive/refs/tags/%{version}.tar.gz
Patch0:         mnemosyne-mga-fix-install.patch

BuildArch:      noarch
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

Requires:       python3-cheroot
Requires:       python3-cherrypy
Requires:       python3-decorator
Requires:       python3-matplotlib-qt6
Requires:       python3-qt6-core
Requires:       python3-qt6-gui
Requires:       python3-qt6-multimedia
Requires:       python3-qt6-sql
Requires:       python3-qt6-widgets
# not provided on 32 bits arches
Recommends:       python3-qt6-webenginewidgets
Requires:       python3-webob
Requires:       python3-googletrans
Requires:       python3-gtts
Requires:       python3-argon2-cffi

%description
Mnemosyne resembles a traditional flash-card program but with an
important twist: it uses a sophisticated algorithm to schedule the best
time for a card to come up for review.

The Mnemosyne project is also a research project into the nature of long-term
memory, to which you can freely choose to participate by sending anonymous
data to a central server for analysis.

Optional dependency:
* texlive: enables entering formulas using LaTeX syntax.
Use the following syntax in a card: <$>LaTeX formula</$>

%prep
%autosetup -p1 

cp openSM2sync/LICENSE LICENSE.openSM2sync

%generate_buildrequires
%pyproject_buildrequires

%build
# pyproject macros install lang files under site-packages, what is wrong
%py3_build
# building .mo files
make -C po

%install
%py3_install

%find_lang %{name}

%files -f %{name}.lang
%doc ChangeLog
%license LICENSE.openSM2sync
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{oname}-%{version}*.egg-info
%{python3_sitelib}/openSM2sync/
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg


%changelog
* Tue Mar 11 2025 papoteur <papoteur> 2.11-2.mga10
+ Revision: 2162754
- rebuild for python3.13

* Wed Sep 04 2024 papoteur <papoteur> 2.11-1.mga10
+ Revision: 2093084
- new version 2.11
- add generate_buildrequires macro
- build mo files, no more provided

* Tue Feb 27 2024 daviddavid <daviddavid> 2.10.1-1.mga10
+ Revision: 2044803
- new version: 2.10.1
- switch to PyQt6

* Tue Feb 27 2024 daviddavid <daviddavid> 2.8-4.mga10
+ Revision: 2044762
- rebuild for py3.12

* Mon Jul 24 2023 wally <wally> 2.8-3.mga9
+ Revision: 1964150
- add missing requires (mga#32131)
  - python3-googletrans
  - python3-gtts
  - python3-argon2-cffi

* Wed Mar 23 2022 umeabot <umeabot> 2.8-2.mga9
+ Revision: 1823037
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 akien <akien> 2.8-1.mga9
+ Revision: 1779141
- Version 2.8

* Fri Jun 04 2021 akien <akien> 2.7.3-2.mga9
+ Revision: 1729622
- Rebuild for Python 3.9

* Thu Nov 26 2020 akien <akien> 2.7.3-1.mga8
+ Revision: 1649382
- Version 2.7.3

* Tue Nov 03 2020 akien <akien> 2.7.2-1.mga8
+ Revision: 1642214
- Version 2.7.2

* Sun Feb 16 2020 umeabot <umeabot> 2.6.1-4.mga8
+ Revision: 1532705
- Mageia 8 Mass Rebuild

* Tue Sep 17 2019 daviddavid <daviddavid> 2.6.1-3.mga8
+ Revision: 1442772
- rebuild for python3.8

* Fri Jan 11 2019 daviddavid <daviddavid> 2.6.1-2.mga7
+ Revision: 1355041
- rebuild for new Python 3.7

* Sun Nov 04 2018 daviddavid <daviddavid> 2.6.1-1.mga7
+ Revision: 1328081
- new version: 2.6.1

* Thu Sep 20 2018 umeabot <umeabot> 2.6-2.mga7
+ Revision: 1279940
- Mageia 7 Mass Rebuild

* Mon May 14 2018 akien <akien> 2.6-1.mga7
+ Revision: 1229428
- Version 2.6

* Sat Aug 05 2017 pterjan <pterjan> 2.5-2.mga7
+ Revision: 1135273
- Rebuild for python 3.6

* Sat Jul 01 2017 akien <akien> 2.5-1.mga6
+ Revision: 1108790
- Version 2.5

* Fri Feb 03 2017 akien <akien> 2.4.1-1.mga6
+ Revision: 1084668
- Version 2.4.1

* Mon Dec 05 2016 akien <akien> 2.4-1.mga6
+ Revision: 1072650
- Version 2.4
- Build with Python 3 and Qt 5

* Tue May 10 2016 akien <akien> 2.3.6-1.mga6
+ Revision: 1012318
- Version 2.3.6

* Sun Dec 13 2015 akien <akien> 2.3.5-1.mga6
+ Revision: 910086
- Version 2.3.5

* Mon Jun 22 2015 akien <akien> 2.3.3-1.mga6
+ Revision: 839478
- Version 2.3.3

* Sun Mar 08 2015 akien <akien> 2.3.2-1.mga5
+ Revision: 818182
- Version 2.3.2

* Fri Oct 17 2014 akien <akien> 2.3.1-1.mga5
+ Revision: 777628
- Add AUR patch to fix conflict between Qt4 and Qt5 in matplotlib
- import mnemosyne from Fedora


* Thu Jun 19 2014 Jiri Popelka <jpopelka@redhat.com> - 2.3.1-1
- 2.3.1

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Apr 03 2014 Jiri Popelka <jpopelka@redhat.com> - 2.3-1
- 2.3

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Apr 15 2013 Jiri Popelka <jpopelka@redhat.com> - 2.2.1-1
- updated to 2.2.1 (no LICENSE file ?)

* Mon Jan 28 2013 Jiri Popelka <jpopelka@redhat.com> - 2.2-3.a
- python-matplotlib moved qt4 backend to -qt4 subpackage (#903760)

* Fri Jan 25 2013 Jiri Popelka <jpopelka@redhat.com> - 2.2-2.a
- updated to 2.2a

* Wed Dec 05 2012 Jiri Popelka <jpopelka@redhat.com> - 2.2-1
- updated to 2.2

* Thu Sep 13 2012 Jiri Popelka <jpopelka@redhat.com> - 2.1-1
- updated to 2.1

* Thu Aug 02 2012 Jiri Popelka <jpopelka@redhat.com> - 2.0.1-1
- updated to 2.0.1

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jun 18 2012 Jiri Popelka <jpopelka@redhat.com> - 2.0-1
- updated to 2.0

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Nov 17 2010 Jiri Popelka <jpopelka@redhat.com> - 1.2.2-3
- requires Python Imaging Library (PIL) (bug #654291)

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1.2.2-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Wed Jul 07 2010 Dominik Mierzejewski <rpm@greysector.net> 1.2.2-1
- updated to 1.2.2
- upstream changelog: http://www.mnemosyne-proj.org/news.php

* Wed Aug 26 2009 Dominik Mierzejewski <rpm@greysector.net> 1.2.1-1
- updated to 1.2.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2-3.r1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2-2.r1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Jan 27 2009 Dominik Mierzejewski <rpm@greysector.net> 1.2-1.r1
- updated to 1.2-r1, fixes https://bugs.launchpad.net/mnemosyne-proj/+bug/252152

* Tue Nov 11 2008 Dominik Mierzejewski <rpm@greysector.net> 1.1.1-3.r1
- fixed .desktop file comment to conform to GNOME HIG
- removed a redundant python setup.py install call
- moved the .desktop file category addition to the patch
- added missing hicolor-icon-theme-requires

* Fri Oct 03 2008 Dominik Mierzejewski <rpm@greysector.net> 1.1.1-2.r1
- updated to 1.1.1-r1
- dropped separate icon (fixed upstream)

* Thu Sep 11 2008 Dominik Mierzejewski <rpm@greysector.net> 1.1.1-1
- initial package
- include fixed icon from 1.1
